package com.ruoyi.zongzhi.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.zongzhi.mapper.TcIdcUnitMapper;
import com.ruoyi.zongzhi.domain.TcIdcUnit;
import com.ruoyi.zongzhi.service.ITcIdcUnitService;

/**
 * IDC单位Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-08-10
 */
@Service
public class TcIdcUnitServiceImpl implements ITcIdcUnitService 
{
    @Autowired
    private TcIdcUnitMapper tcIdcUnitMapper;

    /**
     * 查询IDC单位
     * 
     * @param id IDC单位主键
     * @return IDC单位
     */
    @Override
    public TcIdcUnit selectTcIdcUnitById(Long id)
    {
        return tcIdcUnitMapper.selectTcIdcUnitById(id);
    }

    /**
     * 查询IDC单位列表
     * 
     * @param tcIdcUnit IDC单位
     * @return IDC单位
     */
    @Override
    public List<TcIdcUnit> selectTcIdcUnitList(TcIdcUnit tcIdcUnit)
    {
        return tcIdcUnitMapper.selectTcIdcUnitList(tcIdcUnit);
    }

    /**
     * 新增IDC单位
     * 
     * @param tcIdcUnit IDC单位
     * @return 结果
     */
    @Override
    public int insertTcIdcUnit(TcIdcUnit tcIdcUnit)
    {
        tcIdcUnit.setCreateTime(DateUtils.getNowDate());
        return tcIdcUnitMapper.insertTcIdcUnit(tcIdcUnit);
    }

    /**
     * 修改IDC单位
     * 
     * @param tcIdcUnit IDC单位
     * @return 结果
     */
    @Override
    public int updateTcIdcUnit(TcIdcUnit tcIdcUnit)
    {
        tcIdcUnit.setUpdateTime(DateUtils.getNowDate());
        return tcIdcUnitMapper.updateTcIdcUnit(tcIdcUnit);
    }

    /**
     * 批量删除IDC单位
     * 
     * @param ids 需要删除的IDC单位主键
     * @return 结果
     */
    @Override
    public int deleteTcIdcUnitByIds(Long[] ids)
    {
        return tcIdcUnitMapper.deleteTcIdcUnitByIds(ids);
    }

    /**
     * 删除IDC单位信息
     * 
     * @param id IDC单位主键
     * @return 结果
     */
    @Override
    public int deleteTcIdcUnitById(Long id)
    {
        return tcIdcUnitMapper.deleteTcIdcUnitById(id);
    }
}
